==> haskell-conduit-1.3.6.1-125.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit
version:              1.3.6.1
visibility:           public
id:                   conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
key:                  conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.

    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).

    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.

category:             Data, Conduit
abi:                  b9ea6f97bd9017619ecb3eab5aa5378f
exposed:              True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List

hidden-modules:
    Data.Conduit.Internal.Pipe Data.Conduit.Internal.Conduit
    Data.Conduit.Combinators.Unqualified Data.Streaming.FileRead
    Data.Streaming.Filesystem

import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-1.3.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-1.3.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-1.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit
hs-libraries:         HSconduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    mono-traversable-1.0.21.0-9RUKUQu56O66rvR7vJ1jcU mtl-2.3.1
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html:         /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.3.6.1-126-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit
version:              1.3.6.1
visibility:           public
id:                   conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
key:                  conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.

    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).

    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.

category:             Data, Conduit
abi:                  64ee6ade61a4af00a66e5c7a0dc78bee
exposed:              True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List

hidden-modules:
    Data.Conduit.Internal.Pipe Data.Conduit.Internal.Conduit
    Data.Conduit.Combinators.Unqualified Data.Streaming.FileRead
    Data.Streaming.Filesystem

import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-1.3.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-1.3.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-1.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit
hs-libraries:         HSconduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    mono-traversable-1.0.21.0-DRPwtEa2I1e57PO0WNa046 mtl-2.3.1
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html:         /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
